@@ -27,15 +27,34 @@ from .nodes import (
 )
 
 
-class Workflow:
+class Nodes:
+    """
+    A series of nodes to be executed on call.
+    """
+
+    __slots__ = ("_nodes",)
+
+    def __init__(self, *nodes_: Callable):
+        self._nodes = list(nodes_)
+
+    def __call__(self, context: WorkflowContext):
+        with context:
+            self._execute(context)
+
+    def _execute(self, context: WorkflowContext):
+        for node in self._nodes:
+            node(context)
+
+
+class Workflow(Nodes):
     """
     A workflow definition.
     """
 
-    __slots__ = ("_nodes", "name", "description")
+    __slots__ = ("name", "description")
 
-    def __init__(self, *nodes: Callable, name: str, description: str = None):
-        self._nodes = list(nodes)
+    def __init__(self, *nodes_: Callable, name: str, description: str = None):
+        super().__init__(*nodes_)
         self.name = name
         self.description = description
 
@@ -56,27 +75,18 @@ class Workflow:
         self._execute(context)
         return context
 
-    def _execute(self, context: WorkflowContext):
-        for node in self._nodes:
-            node(context)
-
-    def nodes(self, *nodes: Callable) -> "Workflow":
+    def nodes(self, *nodes_: Callable) -> "Workflow":
         """
         Add additional node(s)
         """
-        self._nodes.extend(nodes)
+        self._nodes.extend(nodes_)
         return self
 
-    steps = nodes
-
-    def nested(
-        self, *nodes: Callable, name: str = None, description: str = None
-    ) -> "Workflow":
+    def nested(self, *nodes_: Callable) -> "Workflow":
         """
         Add nested node(s), nested nodes have their own scope
         """
-        name = name or f"Nested {self.name}"
-        self._nodes.append(Workflow(*nodes, name=name, description=description))
+        self._nodes.append(Nodes(*nodes_))
         return self
 
     def set_vars(self, **kwargs) -> "Workflow":
